@@ -19,7 +19,7 @@ use num_cpus;
 use self::errors::ParseErr;
 
 // Re-export key items from internal modules.
-pub use self::errors::{FileErr, InputIteratorErr};
+pub use self::errors::FileErr;
 
 #[derive(PartialEq)]
 enum Mode { Arguments, Command, Inputs, InputsAppend, Files, FilesAppend }
@@ -34,6 +34,7 @@ pub const DRY_RUN:             u16 = 64;
 pub const SHELL_QUOTE:         u16 = 128;
 pub const ETA:                 u16 = 256;
 pub const JOBLOG:              u16 = 512;
+pub const JOBLOG_8601:         u16 = 1024;
 
 /// `Args` is a collection of critical options and arguments that were collected at
 /// startup of the application.
@@ -66,7 +67,8 @@ impl Args {
 
     /// Performs all the work related to parsing program arguments
     pub fn parse(&mut self, comm: &mut String, arguments: &[String], base_path: &mut PathBuf)
-        -> Result<usize, ParseErr> {
+        -> Result<usize, ParseErr>
+    {
         // Each list will consist of a series of input arguments
         let mut lists: Vec<Vec<String>>     = Vec::new();
         // The `current_inputs` variable will contain all the inputs that have been collected for the first list.
@@ -141,6 +143,7 @@ impl Args {
                                     index += 1;
                                     self.flags |= JOBLOG;
                                 },
+                                "joblog-8601" => self.flags |= JOBLOG_8601,
                                 "jobs" => {
                                     let val = arguments.get(index).ok_or(ParseErr::JobsNoValue)?;
                                     self.ncores = jobs::parse(val)?;
@@ -171,7 +174,7 @@ impl Args {
                                 },
                                 "verbose" => self.flags |= VERBOSE_MODE,
                                 "version" => {
-                                    println!("MIT/Rust Parallel 0.10.1\n");
+                                    println!("MIT/Rust Parallel 0.10.3\n");
                                     exit(0);
                                 },
                                 "tmpdir" | "tempdir" => {
